==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lt/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Patvirtinkite masinio ištrynimo turinį',
  'bulk_delete_help'	=> 'Peržiūrėkite įrangos ištrinimą žemiau. Ištrinus, įranga galima atstatyti, tačiau daugiau nebus priskirta jokiam vartotojam.',
  'bulk_delete_warn'	=> 'Jūs norite ištrinti :asset_count įranga.',
	'bulk_update'		=> 'Visa atnaujinama įranga',
	'bulk_update_help'	=> 'Ši forma leidžia jums atnaujinti kelias įrangas vienu metu. Prašome užpildykite laukelius, kuriuos reikia keisti. Visi laukeliai, kuriuos paliksite tuščius liks nepakeisti. ',
	'bulk_update_warn'	=> 'Jūs ruošiatės keisti sekančius nustatymus :asset_count assets.',
    'checkedout_to'		=> 'Išduota',
    'checkout_date'		=> 'Išdavimo data',
    'checkin_date'		=> 'Priėmimo data',
    'checkout_to'		=> 'Išduota',
    'cost'				=> 'Pirkimo kaina',
    'create'			=> 'Sukurti įrangą',
    'date'				=> 'Pirkimo data',
    'depreciation'	    => 'Nusidėvėjimas',
    'depreciates_on'	=> 'Nusidėvėjimo data',
    'default_location'	=> 'Numatytoji vietovė',
    'eol_date'			=> 'Irangos naudojimo pabaigos data',
    'eol_rate'			=> 'Įrangos naudojimo pabaigos likutis',
    'expected_checkin'  => 'Tikėtina priėmimo data',
    'expires'			=> 'Baigiasi',
    'fully_depreciated'	=> 'Visiškai nusidėvėjo',
    'help_checkout'		=> 'Jei jūs norite susieti šią įrangą iš karto, pasirinkite "pasiruoštas naudojimui" iš anksčiau esanšios būklės sąrašo. ',
    'mac_address'		=> 'MAC adresas',
    'manufacturer'		=> 'Gamintojas',
    'model'				=> 'Modelis',
    'months'			=> 'mėnesiai',
    'name'				=> 'Įrangos pavadinimas',
    'notes'				=> 'Pastabos',
    'order'				=> 'Užsakymo numeris',
    'qr'				=> 'QR kodas',
    'requestable'		=> 'Naudotojai galintys gauti šią įrangą',
    'select_statustype'	=> 'Parinkti būklės tipą',
    'serial'			=> 'Serijinis numeris',
    'status'			=> 'Būklė',
    'tag'				=> 'Įrangos pavadinimas',
    'update'			=> 'Įrangos atnaujinimas',
    'warranty'			=> 'Garantija',
		'warranty_expires'		=> 'Garantija baigiasi',
    'years'				=> 'metai',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lt/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Patvirtinkite masinio ištrynimo turinį',
  'bulk_delete_help'	=> 'Peržiūrėkite įrangos ištrinimą žemiau. Ištrinus, įranga galima atstatyti, tačiau daugiau nebus priskirta jokiam vartotojam.',
  'bulk_delete_warn'	=> 'Jūs norite ištrinti :asset_count įranga.',
    'bulk_update'		=> 'Visa atnaujinama įranga',
    'bulk_update_help'	=> 'Ši forma leidžia jums atnaujinti kelias įrangas vienu metu. Prašome užpildykite laukelius, kuriuos reikia keisti. Visi laukeliai, kuriuos paliksite tuščius liks nepakeisti. ',
    'bulk_update_warn'	=> 'Jūs ruošiatės keisti sekančius nustatymus :asset_count assets.',
    'checkedout_to'		=> 'Išduota',
    'checkout_date'		=> 'Išdavimo data',
    'checkin_date'		=> 'Priėmimo data',
    'checkout_to'		=> 'Išduota',
    'cost'				=> 'Pirkimo kaina',
    'create'			=> 'Sukurti įrangą',
    'date'				=> 'Pirkimo data',
    'depreciation'	    => 'Nusidėvėjimas',
    'depreciates_on'	=> 'Nusidėvėjimo data',
    'default_location'	=> 'Numatytoji vietovė',
    'eol_date'			=> 'Irangos naudojimo pabaigos data',
    'eol_rate'			=> 'Įrangos naudojimo pabaigos likutis',
    'expected_checkin'  => 'Tikėtina priėmimo data',
    'expires'			=> 'Baigiasi',
    'fully_depreciated'	=> 'Visiškai nusidėvėjo',
    'help_checkout'		=> 'Jei jūs norite susieti šią įrangą iš karto, pasirinkite "pasiruoštas naudojimui" iš anksčiau esanšios būklės sąrašo. ',
    'mac_address'		=> 'MAC adresas',
    'manufacturer'		=> 'Gamintojas',
    'model'				=> 'Modelis',
    'months'			=> 'mėnesiai',
    'name'				=> 'Įrangos pavadinimas',
    'notes'				=> 'Pastabos',
    'order'				=> 'Užsakymo numeris',
    'qr'				=> 'QR kodas',
    'requestable'		=> 'Naudotojai galintys gauti šią įrangą',
    'select_statustype'	=> 'Parinkti būklės tipą',
    'serial'			=> 'Serijinis numeris',
    'status'			=> 'Būklė',
    'tag'				=> 'Įrangos pavadinimas',
    'update'			=> 'Įrangos atnaujinimas',
    'warranty'			=> 'Garantija',
        'warranty_expires'		=> 'Garantija baigiasi',
    'years'				=> 'metai',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
